@@ -29,7 +29,7 @@
 #include <safer.h>
 #include <cast.h>
 #include <tean.h>
-#include <twofish/aes.h>
+#include <aes.h>
 #include <xmemory.h>
 #include <rc2.h>
 #include <rc6.h>
@@ -1128,18 +1128,6 @@ char *x=mxmalloc(20);
     return x;
     break;
 
-#ifdef MCRYPT2
-   case CRYPT:
-    strcpy(x,"Crypt");
-    return x;
-    break;
-
-   case DES_COMPAT:
-    strcpy(x,"DES-COMPAT");
-    return x;
-    break;
-#endif
-
    case BLOWFISH:
     strcpy(x,"Blowfish");
     return x;
@@ -1197,10 +1185,6 @@ int is_ok_algorithm(int algorithm) {
 #endif
    case TripleDES:
    case ThreeWAY:
-#ifdef MCRYPT2
-   case CRYPT:
-   case DES_COMPAT:
-#endif
    case BLOWFISH:
    case TWOFISH128:
    case TWOFISH192:
@@ -1240,12 +1224,11 @@ int is_ok_mode(int mode) { /* if this mode exists returns 0 */
 
 
 void gen_key(void *keyword, void *salt, size_t salt_size, size_t key_size,
-             unsigned char *password)
+             unsigned char *password, int plen)
 {
         unsigned char   key[MAX_KEY_LEN];
         SHA1_CTX        ctx;
         unsigned char   *digest;  
-        int             plen    = strlen((void*)password);
         size_t          size    = key_size;
         unsigned char   *cp     = key,
                         *cp0    = key;
